PathSegment

Enum PathSegment 

pub enum PathSegment {
    MoveTo {
        abs: bool,
        x: f64,
        y: f64,
    },
    LineTo {
        abs: bool,
        x: f64,
        y: f64,
    },
    HorizontalLineTo {
        abs: bool,
        x: f64,
    },
    VerticalLineTo {
        abs: bool,
        y: f64,
    },
    CurveTo {
        abs: bool,
        x1: f64,
        y1: f64,
        x2: f64,
        y2: f64,
        x: f64,
        y: f64,
    },
    SmoothCurveTo {
        abs: bool,
        x2: f64,
        y2: f64,
        x: f64,
        y: f64,
    },
    Quadratic {
        abs: bool,
        x1: f64,
        y1: f64,
        x: f64,
        y: f64,
    },
    SmoothQuadratic {
        abs: bool,
        x: f64,
        y: f64,
    },
    EllipticalArc {
        abs: bool,
        rx: f64,
        ry: f64,
        x_axis_rotation: f64,
        large_arc: bool,
        sweep: bool,
        x: f64,
        y: f64,
    },
    ClosePath {
        abs: bool,
    },
}
Representation of a path segment.

If you want to change the segment type (for example MoveTo to LineTo) you should create a new segment. But you still can change points or make segment relative or absolute.

Variants



MoveTo

Fields

abs: bool


LineTo

Fields

abs: bool


HorizontalLineTo

Fields

abs: bool


VerticalLineTo

Fields

abs: bool


CurveTo

Fields

abs: bool
x1: f64
y1: f64
x2: f64
y2: f64


SmoothCurveTo

Fields

abs: bool
x2: f64
y2: f64


Quadratic

Fields

abs: bool
x1: f64
y1: f64


SmoothQuadratic

Fields

abs: bool


EllipticalArc

Fields

abs: bool
rx: f64
ry: f64
x_axis_rotation: f64
large_arc: bool
sweep: bool


ClosePath

Fields

abs: bool

Implementations

Source

impl PathSegment

pub fn is_abs(&self) -> bool

Returns true if the segment is absolute.

Examples
use svgtypes::{PathParser, PathSegment};

let mut segments = Vec::new();
for segment in PathParser::from("M10-20l30.1.5.1-20z") {
    segments.push(segment.unwrap());
}

assert_eq!(segments[0].is_abs(), true);
assert_eq!(segments[1].is_abs(), false);
assert_eq!(segments[2].is_abs(), false);
assert_eq!(segments[3].is_abs(), false);
pub fn command(&self) -> u8

Returns the segment letter.

Examples
use svgtypes::{PathParser, PathSegment};

let mut segments = Vec::new();
for segment in PathParser::from("M10-20l30.1.5.1-20z") {
    segments.push(segment.unwrap());
}

assert_eq!(segments[0].command(), b'M');
assert_eq!(segments[1].command(), b'l');
assert_eq!(segments[2].command(), b'l');
assert_eq!(segments[3].command(), b'z');